==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/core/classes/Http/FileStringResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1e" . "c2d6653e8a" . "0ab7848e53" . "6215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5" . "36215"] ?: array()) + array("_aa19f39560a41402209bf53" . "2d1544744" => base64_decode("c2VuZEhlYWRlcnNEb3d" . "ubG9hZA=="), "_b900ff57c02d0c496c3d0671e" . "0c7ab71" => base64_decode("aHR0cF9mdW5jdGl" . "vbnMucGhw"), "_63c3fcd4498ce3d69ed26ee" . "228563cba" => base64_decode("V" . "Q" . "=" . "="));
use Symfony\Component\HttpFoundation\Response;







class FileStringResponse extends Response
{
    const INLINE = 'inline';
    const DOWNLOAD = 'attachment';
    protected $file_name;
    protected $disposition;
    protected $mime_type;
    protected $last_modified;
    protected $is_protected;
    protected $cache_ttl;
    protected $file_size;
    public function __construct($_24ca62b4d01cc6d515dfd0bea4c9d59a, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0 = false, $_655a561f4e34bbdfa745dc13393471b3 = '')
    {
        parent::__construct($_24ca62b4d01cc6d515dfd0bea4c9d59a);
        $this->file_name = $file_name;
        $this->disposition = $_4b83d26c5eb0d93a0b377ff582df05e0 ? self::DOWNLOAD : self::INLINE;
        $this->mime_type = $_655a561f4e34bbdfa745dc13393471b3;
        $this->last_modified = 0;
        $this->is_protected = 1;
        $this->cache_ttl = 604800;
        
        
        $this->file_size = 0;
    }
    
    
    
    
    
    
    public function SetMimeType($_655a561f4e34bbdfa745dc13393471b3)
    {
        $this->mime_type = $_655a561f4e34bbdfa745dc13393471b3;
        return $this;
    }
    
    
    
    
    
    
    public function SetLastModified(\DateTimeInterface $_7608a2690229dd26ac43cb60aa2a7d97 = null)
    {
        if ($_7608a2690229dd26ac43cb60aa2a7d97 !== null) {
            $this->last_modified = $_7608a2690229dd26ac43cb60aa2a7d97->format($GLOBALS["__65da1b1ec2d6653e8a0ab7848e" . "536215"]["_63c3fcd" . "4498ce3d" . "69ed26ee" . "228563cb" . "a"]);
        }
        $this->last_modified = $_7608a2690229dd26ac43cb60aa2a7d97;
        return $this;
    }
    
    
    
    
    
    
    public function SetIsProtected($_fb01886968e6069b1e01895aab49a296)
    {
        $this->is_protected = (bool) $_fb01886968e6069b1e01895aab49a296;
        return $this;
    }
    
    
    
    
    
    
    public function SetCacheTTL($_3eda9235d1e262356cb51c8c4f40b84b)
    {
        $this->cache_ttl = $_3eda9235d1e262356cb51c8c4f40b84b;
        return $this;
    }
    public function sendHeaders()
    {
        require_once $GLOBALS["__65da1b1ec2d6653e8a0ab7848e53621" . "5"]["_b900ff57c02d0c496c3d0671e" . "0c7ab71"];
        $GLOBALS["__65da1b1ec2d6653" . "e8a0ab7848e536215"]["_aa19f39560a4" . "1402209bf532d" . "1544744"]($this->file_name, $this->disposition, $this->mime_type, $this->file_size, $this->last_modified, $this->cache_ttl, $this->is_protected);
        return $this;
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/core/classes/Http/FileStringResponse.php <==
<?php
namespace Claromentis\Core\Http;

$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"] ?: array()) + array("_b900ff57c02d0c4" . "96c3d0671e0c7ab7" . "1" => base64_decode("aHR0cF9mdW5j" . "dGlvbnMucGhw"), "_63c3fcd" . "4498ce3d" . "69ed26ee" . "228563cb" . "a" => base64_decode("VQ=" . "="), "_aa19f39560a41402209bf532d15447" . "44" => base64_decode("c2VuZEhlYWRlc" . "nNEb3dubG9hZA" . "=="));
use Symfony\Component\HttpFoundation\Response;







class FileStringResponse extends Response
{
    const INLINE = 'inline';
    const DOWNLOAD = 'attachment';
    protected $file_name;
    protected $disposition;
    protected $mime_type;
    protected $last_modified;
    protected $is_protected;
    protected $cache_ttl;
    protected $file_size;
    public function __construct($_24ca62b4d01cc6d515dfd0bea4c9d59a, $file_name, $_4b83d26c5eb0d93a0b377ff582df05e0 = false, $_655a561f4e34bbdfa745dc13393471b3 = '')
    {
        parent::__construct($_24ca62b4d01cc6d515dfd0bea4c9d59a);
        $this->file_name = $file_name;
        $this->disposition = $_4b83d26c5eb0d93a0b377ff582df05e0 ? self::DOWNLOAD : self::INLINE;
        $this->mime_type = $_655a561f4e34bbdfa745dc13393471b3;
        $this->last_modified = 0;
        $this->is_protected = 1;
        $this->cache_ttl = 604800;
        
        
        $this->file_size = 0;
    }
    
    
    
    
    
    
    public function SetMimeType($_655a561f4e34bbdfa745dc13393471b3)
    {
        $this->mime_type = $_655a561f4e34bbdfa745dc13393471b3;
        return $this;
    }
    
    
    
    
    
    
    public function SetLastModified(\DateTimeInterface $_7608a2690229dd26ac43cb60aa2a7d97 = null)
    {
        if ($_7608a2690229dd26ac43cb60aa2a7d97 !== null) {
            $this->last_modified = $_7608a2690229dd26ac43cb60aa2a7d97->format($GLOBALS["__65da1b1ec2d6" . "653e8a0ab7848e" . "536215"]["_63c3fcd4498ce3d69ed26ee228" . "563cba"]);
        }
        $this->last_modified = $_7608a2690229dd26ac43cb60aa2a7d97;
        return $this;
    }
    
    
    
    
    
    
    public function SetIsProtected($_fb01886968e6069b1e01895aab49a296)
    {
        $this->is_protected = (bool) $_fb01886968e6069b1e01895aab49a296;
        return $this;
    }
    
    
    
    
    
    
    public function SetCacheTTL($_3eda9235d1e262356cb51c8c4f40b84b)
    {
        $this->cache_ttl = $_3eda9235d1e262356cb51c8c4f40b84b;
        return $this;
    }
    public function sendHeaders()
    {
        require_once $GLOBALS["__65da1b1ec2d6653e" . "8a0ab7848e536215"]["_b900ff57c02d0c496c" . "3d0671e0c7ab71"];
        $GLOBALS["__65da1b1ec2d6653e8a0" . "ab7848e536215"]["_aa19f39560a41402209bf532d1544" . "744"]($this->file_name, $this->disposition, $this->mime_type, $this->file_size, $this->last_modified, $this->cache_ttl, $this->is_protected);
        return $this;
    }
}
